"""Top-level package for Wikidata Curation Tools."""

__author__ = """Tiago Lubiana"""
__email__ = "tiago.lubiana.alves@usp.br"
__version__ = '0.1.1'

from .wdcuration import search_wikidata, add_key, render_qs_url, lookup_id, today_in_quickstatements
